<template>
  <el-card shadow="never" class="aui-card--fill">
    <div class="mod-index-full">
      <el-form :inline="true" :model="dataForm" label-width="100px">
        <el-form-item :label="$t('datePicker.date')">
          <el-date-picker
              v-model="dataForm.dateRange"
              type="datetimerange"
              format="yyyy-MM-dd HH:mm"
              value-format="yyyy-MM-dd HH:mm"
              range-separator="至"
              start-placeholder="开始日期"
              end-placeholder="结束日期">
          </el-date-picker>
        </el-form-item>
        <el-form-item label="商品煤种">
          <dict-select-tag style="width: 100%"
                           v-model="dataForm.index"
                           placeholder="商品煤种"
                           dictCode="spmz"
                           :clearable="false"/>
        </el-form-item>
        <el-form-item>
          <el-button @click="queryChart()">{{ $t('query') }}</el-button>
        </el-form-item>
      </el-form>
    </div>
     <div id="chartLineBox" style="width: 90%;height: 70vh;"> </div>
  </el-card>
</template>
<script>
  import DictSelectTag from "@/components/dict/dict-select-tag";
  import BarLine from "@/components/chart/bar-line";
  import {getYMD} from "@/utils/dateUtils";
  import * as echarts from 'echarts'

  export default {
    components: {DictSelectTag, BarLine},
    data() {
      return {
        loading: false,
        chartOption: {},
        dataForm: {
          groupType: 'day',
          dateRange: [],
          index: ''
        }
      }
    },
    mounted() {
        this.chartLine = echarts.init(document.getElementById('chartLineBox'));
 
        // 指定图表的配置项和数据
        var option = {
            tooltip: {              //设置tip提示
                trigger: 'axis'
            },
            color: ['#869ad7'],       //设置区分（每条线是什么颜色，和 legend 一一对应）
            xAxis: {                //设置x轴
            boundaryGap: false,
                type: 'category',
                boundaryGap: false,     //坐标轴两边不留白
                data: ['2023-5-31', '2023-6-1', '2023-6-2', '2023-6-3', '2023-6-4', '2023-6-5', '2023-6-6','2023-6-7',],
                name: '日期',           //X轴 name
                nameTextStyle: {        //坐标轴名称的文字样式
                    color: 'black',
                    fontSize: 16,
                    padding: [0, 0, 0, 20]
                },
                axisLine: {             //坐标轴轴线相关设置。
                    lineStyle: {
                        color: 'black',
                    }
                }
            },
            yAxis: {
                nameTextStyle: {
                    color: 'black',
                    fontSize: 16,
                    padding: [0, 0, 10, 0]
                },
                axisLine: {
                    lineStyle: {
                        color: 'black',
                    }
                },
                type: 'value'
            },
            series: [
              {
                areaStyle: {},
                name: '销售数量',
                data: [123,41,144,200,56,74,282,192],
                type: 'line',
                lineStyle: {
                    normal: {
                        color: '#869ad7',
                    }
                },
              }
          ]
        };
 
        // 使用刚指定的配置项和数据显示图表。
        this.chartLine.setOption(option);
    
    },
    methods: {
      init() {
        this.dataForm.dateRange = []
        this.dataForm.dateRange.push(getYMD(new Date().getTime() - 3600 * 1000 * 24 * 30) + ' 00:00')
        this.dataForm.dateRange.push(getYMD(new Date()) + ' 23:59')
      },

      queryChart() {
        let params = {
          groupType: this.dataForm.groupType,
          startDate: this.dataForm.dateRange[0] + ':00',
          endDate: this.dataForm.dateRange[1] + ':59',
          index: this.dataForm.index
        }
        this.loading = true
        this.$http.post(`/iailab-iems-coal-proddisp/analysis/index/chart`, params).then(({data: res}) => {
          this.loading = false
          if (res.code !== 0) {
            return this.$message.error(res.msg)
          }
          let series = []
          if (res.data.series) {
            res.data.series.forEach(function (item) {
              series.push(
                {
                  name: item.name,
                  data: item.data,
                  type: 'line',
                  smooth: false
                }
              )
            })
          }

          this.chartOption = {
            grid: {
              top: '8%',
              right: '10%',
              bottom: '12%',
              left: '10%'
            },
            legend: {
              type: 'scroll',
              orient: 'vertical',
              right: 5,
              top: 20,
              bottom: 20,
              data: res.data.legend
            },
            toolbox: {
              show: true,
              top: 0,
              right: '10%',
              feature: {
                dataView: {readOnly: false},
                magicType: {type: ['line', 'bar']},
                saveAsImage: {}
              }
            },
            xAxis: {
              type: 'category',
              data: res.data.categories
            },
            yAxis: {
              type: 'value',
              name: res.data.valueName,
              nameTextStyle: {
                fontWeight: 'bold'
              },
              axisLine: {
                show: true
              }
            },
            series: series
          }

        }).catch(() => {
          this.loading = false
        })
      }
    }
  }
</script>
